# gzip

**DOI:** [10.5281/zenodo.7034359](https://doi.org/10.5281/zenodo.7034359)

## Available Versions
- **Version 1.9.0**
  - [Download](https://zenodo.org/record/7034360/files/gzip_1.9.0.img)
  - **MD5:** `42a44db7f5c4f698671fc0eabdcddfc5`
  - **DOI:** [10.5281/zenodo.7034360](https://doi.org/10.5281/zenodo.7034360)
  - **Size:** 3.36 MB
  - **Binaries:** 0 available

## Binaries (2 total)

```gzip gunzip```
